<?php

namespace Drupal\sitewide_alert;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Cache\CacheableMetadata;

/**
 * Sitewide Alert placeholder render array builder service.
 *
 * Used in default page_top display and by block submodule.
 */
class SitewideAlertRenderer {

  /**
   * Module configuration.
   *
   * @var \Drupal\Core\Config\ConfigInterface
   */
  protected $config;

  /**
   * The admin context service.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  protected $adminContext;

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $configFactory
   *   Config factory service.
   * @param \Drupal\Core\Routing\AdminContext $adminContext
   *   Admin context service.
   */
  public function __construct(ConfigFactory $configFactory, AdminContext $adminContext) {
    $this->config = $configFactory->get('sitewide_alert.settings');
    $this->adminContext = $adminContext;
  }

  /**
   * Construct the sitewide-alert placeholder render array.
   *
   * @param bool $adminAware
   *   Used to indicate a non-block context, where showing the alert on
   *   admin pages is configurable. When using blocks, block placement is
   *   per theme so this setting is ignored.
   */
  public function build(bool $adminAware = TRUE) : array {
    $cacheMetadata = CacheableMetadata::createFromObject($this->config);

    // Do not show alert on admin pages if we are not configured to do so.
    if ($adminAware && !$this->config->get('show_on_admin') &&
      $this->adminContext->isAdminRoute()) {
      // Populate an empty render array with cache-metadata to force it to
      // invalidate when settings change.
      $build = [];
      $cacheMetadata->applyTo($build);
      return $build;
    }

    $build = [
      '#markup' => '<div data-sitewide-alert></div>',
      '#attached' => [
        'library' => [
          'sitewide_alert/init',
        ],
        'drupalSettings' => [
          'sitewideAlert' => [
            'refreshInterval' => ($this->config->get('refresh_interval') ?? 15) * 1000,
            'automaticRefresh' => ($this->config->get('automatic_refresh') == 1),
          ],
        ],
      ],
    ];
    $cacheMetadata->applyTo($build);
    return $build;
  }

}
